==> haskell-openssl-streams-1.2.3.0-320.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-7kPgnqHgice37gZryitu4h
key:                  openssl-streams-1.2.3.0-7kPgnqHgice37gZryitu4h
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  ca574b5125266f9d1ca1388f2098e575
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-7kPgnqHgice37gZryitu4h
depends:
    HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F base-4.18.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-GBIxq3Y3ahG4K7ipZI07Kf
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.3.0-321-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-HSeJnCaVgDl3xrEX4ZnM8v
key:                  openssl-streams-1.2.3.0-HSeJnCaVgDl3xrEX4ZnM8v
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  fedb6818f4db994df282d058dc6ef072
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-HSeJnCaVgDl3xrEX4ZnM8v
depends:
    HsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR base-4.18.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-6dLtg5IQso2LoK2aAZRuxZ
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
